<?php
/**
 * Description of plumba
 *
 * @author plumba
 */
class Plumba_Main {


	function __construct() {

		//Set hook init to this class init function
		add_action( 'init', array( &$this, 'init' ) );

		$this->add_metaboxes();

		//override if deleting plumba comments
		add_action( 'delete_comment', array( &$this, 'delete_comment' ) );

		add_action( 'media_buttons_context', array( $this, 'media_buttons_context' ) );

		//add some content to the bottom of the page
		//This will be shown in the inline modal
		add_action( 'admin_footer', array( &$this, 'add_inline_popup_content' ) );

		add_shortcode( 'plumba', array( &$this, 'shortcode_plumba' ) );

	}

	//Initial all public functions at startup
	function init() {

		$this->add_postypes();

	}

	//Adds custom posttypes to WP
	function add_postypes() {

		//Adding the common plumba posttype to WP
		$result = register_post_type(
			'plumba_qa',
			array(
				'label' => 'Plumba',
				'description' => 'Stores Questions and Answers to WordPress as Custom Post Type',
				'public' => true,
				'show_ui' => true,
				'show_in_menu' => true,
				'capability_type' => 'post',
				'hierarchical' => false,
				'rewrite' => array( 'slug' => '' ),
				'query_var' => true,
				'exclude_from_search' => true,
				'supports' => array( 'title', 'editor', ),
			'labels' => array(
				'name'               => 'Plumba',
				'singular_name'      => 'Plumba',
				'menu_name'          => 'Plumba',
				'add_new'            => 'Add Plumba',
				'add_new_item'       => 'Add New Plumba',
				'edit'               => 'Edit',
				'edit_item'          => 'Edit Plumba',
				'new_item'           => 'New Plumba',
				'view'               => 'View Plumba',
				'view_item'          => 'View Plumba',
				'search_items'       => 'Search Plumba',
				'not_found'          => 'No Plumba Found',
				'not_found_in_trash' => 'No Plumba Found in Trash',
				'parent'             => 'Parent Plumba',
				)
			)
		);

		if ( is_wp_error( $result ) ) return false;

		if ( ! is_object( $result ) ) return false;

		return true;
	}

	//Add functions for shortcodes in WP
	function add_shortcodes() {
		return false;
	}

	//Adds metaboxes to specific post type
	function add_metaboxes() {
		$nada = new Plumba_Metabox();
		return $nada;
	}

	//When deleting spam, copy to new so that data is preserved!
	function delete_comment( $comment_id ) {

		if ( ! isset( $comment_id ) ) return 0;

		if ( ! $comment = get_comment( $comment_id ) )
			return $comment_id;

		if ( $comment->comment_type == 'plumba_vote' ) {
			Plumba_Comments::create_vote_comment( $comment->comment_post_ID, $comment->comment_content );
		}

		return $comment_id;

	}


	function media_buttons_context( $context ) {

		$post_id   = ! empty( $_GET['post'] ) ? (int) $_GET['post'] : 0;
		$post_type = get_post_type( $post_id );

		if ( $post_type == 'plumba_qa' ) return $context;

		$image_btn = WP_PLUGIN_URL . '/plumba/images/plumba.png';
		$out       = '<a href="#TB_inline?width=250&height=200&inlineId=popup_plumba" class="thickbox" title="' . __( 'Add Plumba Poll', 'plumba' ) . '"><img src="' . $image_btn . '" alt="' . __( 'Add Plumba Poll', 'plumba' ) . '" /></a>';
		return $context . $out;
	}

	function add_inline_popup_content() {
		?>
  <!--suppress ALL -->
  <div id="popup_plumba" style="display:none;">
      <h2>Plumba</h2>

      <p><?php _e( 'Choose a plumba post to insert into post!', 'plumba' ); ?></p>

      <p>
          <!--suppress HtmlFormInputWithoutLabel -->
          <select id="plumba_select">
						<?php
						$args  = array(
							'numberposts'      => - 1,
							'orderby'          => 'post_date',
							'order'            => 'DESC',
							'post_type'        => 'plumba_qa',
							'post_status'      => 'publish',
							'suppress_filters' => true,
						);
						$posts = get_posts( $args );
		foreach ( $posts as $post ) {
			echo '<option value="' . $post->ID . '">' . $post->post_title . '</option>';
		}
						?>
          </select>
      </p>

      <p>
          <input type="button"
                 onclick="var shortcode='[plumba id='+jQuery('#plumba_select').val()+']'; tinyMCE.activeEditor.execCommand('mceInsertContent', 0, shortcode); tb_remove();"
                 class="button-primary" value="<?php _e( 'Insert', 'plumba' ); ?>" />&nbsp;
          <input type="button" onclick="tb_remove();" class="button-secondary"
                 value="<?php _e( 'Cancel', 'plumba' ); ?>" />
      </p>
  </div>
	<?php
	}

	function shortcode_plumba( $attributes ) {

		$arguments = shortcode_atts( array( 'id' => 0 ), $attributes );

		$presentation = new Plumba_Presentation();

		return $presentation->display( $arguments['id'] );

	}


}

?>
